==> libgda-0.2.1.tar.gz: libgda-0.2.1/providers/gda-sybase-server/main-sybase.c <==
/* 
 * $Id: main-sybase.c,v 1.4 2000/11/27 17:50:27 rodrigo Exp $
 * 
 * GNOME DB sybase Provider
 * Copyright (C) 2000 Rodrigo Moya
 * Copyright (C) 2000 Stephan Heinze
 * Copyright (C) 2000 Holger Thon
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "gda-sybase.h"

static Gda_ServerImpl*         server_impl = NULL;
static Gda_ServerImplFunctions server_impl_functions =
{
  gda_sybase_connection_new,
  gda_sybase_connection_open,
  gda_sybase_connection_close,
  gda_sybase_connection_begin_transaction,
  gda_sybase_connection_commit_transaction,
  gda_sybase_connection_rollback_transaction,
  gda_sybase_connection_open_schema,
  gda_sybase_connection_modify_schema,
  gda_sybase_connection_start_logging,
  gda_sybase_connection_stop_logging,
  gda_sybase_connection_create_table,
  gda_sybase_connection_supports,
  gda_sybase_connection_get_gda_type,
  gda_sybase_connection_get_c_type,
  gda_sybase_connection_free,

  gda_sybase_command_new,
  gda_sybase_command_execute,
  gda_sybase_command_free,

  gda_sybase_recordset_new,
  gda_sybase_recordset_move_next,
  gda_sybase_recordset_move_prev,
  gda_sybase_recordset_close,
  gda_sybase_recordset_free,

  gda_sybase_error_make
};

gint
main (gint argc, gchar *argv[])
{
  CORBA_Environment ev;
  CORBA_ORB         orb;

  /* initialize CORBA stuff */
  gda_server_init("gda-sybase-srv", VERSION, argc, argv);

  /* register the server implementation */
  server_impl = gda_server_impl_new("OAFIID:gda-sybase:f212f5f3-8365-4c52-b1c1-b67f9e7b2550",
                                    &server_impl_functions);
  if (server_impl)
    {
      gda_server_impl_start(server_impl);
    }
  else gda_log_error(_("Could not register gda-sybase provider implementation"));
  return 0;
}

==> libgda-0.2.3.tar.gz: libgda-0.2.3/providers/gda-sybase-server/main-sybase.c <==
/* 
 * $Id: main-sybase.c,v 1.5 2000/12/18 15:32:14 rodrigo Exp $
 * 
 * GNOME DB sybase Provider
 * Copyright (C) 2000 Rodrigo Moya
 * Copyright (C) 2000 Stephan Heinze
 * Copyright (C) 2000 Holger Thon
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "gda-sybase.h"

static Gda_ServerImpl*         server_impl = NULL;
static Gda_ServerImplFunctions server_impl_functions =
{
  gda_sybase_connection_new,
  gda_sybase_connection_open,
  gda_sybase_connection_close,
  gda_sybase_connection_begin_transaction,
  gda_sybase_connection_commit_transaction,
  gda_sybase_connection_rollback_transaction,
  gda_sybase_connection_open_schema,
  gda_sybase_connection_modify_schema,
  gda_sybase_connection_start_logging,
  gda_sybase_connection_stop_logging,
  gda_sybase_connection_create_table,
  gda_sybase_connection_supports,
  gda_sybase_connection_get_gda_type,
  gda_sybase_connection_get_c_type,
  gda_sybase_connection_free,

  gda_sybase_command_new,
  gda_sybase_command_execute,
  gda_sybase_command_free,

  gda_sybase_recordset_new,
  gda_sybase_recordset_move_next,
  gda_sybase_recordset_move_prev,
  gda_sybase_recordset_close,
  gda_sybase_recordset_free,

  gda_sybase_error_make
};

gint
main (gint argc, gchar *argv[])
{
  CORBA_Environment ev;
  CORBA_ORB         orb;

  /* initialize CORBA stuff */
  gda_server_init("gda-sybase-srv", VERSION, argc, argv);

  /* register the server implementation */
  server_impl = gda_server_impl_new("OAFIID:GNOME_GDA_Provider_Sybase_ConnectionFactory",
                                    &server_impl_functions);
  if (server_impl)
    {
      gda_server_impl_start(server_impl);
    }
  else gda_log_error(_("Could not register gda-sybase provider implementation"));
  return 0;
}
